@@ -1,12 +1,12 @@
 # Copyright (c) 2007-2008 Infrae. All rights reserved.
-# $Id: Native.py 31670 2008-10-31 10:21:14Z sylvain $
+# $Id: Native.py 31679 2008-10-31 12:06:25Z sylvain $
 
 from pysvn import wc_status_kind, opt_revision_kind, wc_notify_action
 import pysvn
 
-from Common import BaseRecipe, checkExistPath, prepareURLs
+from Common import BaseRecipe, prepareURLs
+from Common import checkAddedPaths, checkExistPath
 
-from sets import Set            # For python 2.3 compatibility
 import os
 import re
 
@@ -121,13 +121,7 @@ def uninstall(name, options):
     if not checkExistPath(location):
         return
 
-    current_paths = Set([os.path.join(location, s) for s in
-                         os.listdir(location)])
-    recipe_paths = Set(urls.keys())
-    added_paths = current_paths.difference(recipe_paths)
-    if added_paths:
-        msg = "New path have been added to the location: %s."
-        raise ValueError(msg % ', '.join(added_paths))
+    checkAddedPaths(location, urls)
 
     for path in urls.keys():
         if not checkExistPath(path):
